==> openui5-1.54.7-javadoc.jar: sap/ui/unified/designtime/library-preload.designtime.js <==
/*!
 * UI development toolkit for HTML5 (OpenUI5)
 * (c) Copyright 2009-2018 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */
sap.ui.predefine('sap/ui/unified/designtime/Calendar.designtime',[],function(){"use strict";return{palette:{group:"INPUT",icons:{svg:"sap/ui/unified/designtime/Calendar.icon.svg"}}};},false);
sap.ui.predefine('sap/ui/unified/designtime/CalendarDateInterval.designtime',[],function(){"use strict";return{name:{singular:"CALENDARDATEINTERVAL_NAME",plural:"CALENDARDATEINTERVAL_NAME_PLURAL"},palette:{group:"INPUT"},templates:{create:"sap/ui/unified/designtime/CalendarDateInterval.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/CalendarLegend.designtime',[],function(){"use strict";return{name:{singular:"CALENDARLEGEND_NAME",plural:"CALENDARLEGEND_NAME_PLURAL"},palette:{group:"DISPLAY"},templates:{create:"sap/ui/unified/designtime/CalendarLegend.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/Currency.designtime',[],function(){"use strict";return{name:{singular:"CURRENCY_NAME",plural:"CURRENCY_NAME_PLURAL"},palette:{group:"DISPLAY",icons:{svg:"sap/ui/unified/designtime/Currency.icon.svg"}},templates:{create:"sap/ui/unified/designtime/Currency.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/FileUploader.designtime',[],function(){"use strict";return{palette:{group:"INPUT",icons:{svg:"sap/ui/unified/designtime/FileUploader.icon.svg"}}};},false);
sap.ui.predefine('sap/ui/unified/designtime/library.designtime',[],function(){"use strict";return{};});
//# sourceMappingURL=library-preload.designtime.js.map

==> openui5-1.70.0-javadoc.jar: sap/ui/unified/designtime/library-preload.designtime.js <==
//@ui5-bundle sap/ui/unified/designtime/library-preload.designtime.js
/*!
 * OpenUI5
 * (c) Copyright 2009-2019 SAP SE or an SAP affiliate company.
 * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */
sap.ui.predefine('sap/ui/unified/designtime/Calendar.designtime',[],function(){"use strict";return{palette:{group:"INPUT",icons:{svg:"sap/ui/unified/designtime/Calendar.icon.svg"}}};},false);
sap.ui.predefine('sap/ui/unified/designtime/CalendarDateInterval.designtime',[],function(){"use strict";return{name:{singular:"CALENDARDATEINTERVAL_NAME",plural:"CALENDARDATEINTERVAL_NAME_PLURAL"},palette:{group:"INPUT",icons:{svg:"sap/ui/unified/designtime/CalendarDateInterval.icon.svg"}},templates:{create:"sap/ui/unified/designtime/CalendarDateInterval.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/CalendarLegend.designtime',[],function(){"use strict";return{name:{singular:"CALENDARLEGEND_NAME",plural:"CALENDARLEGEND_NAME_PLURAL"},palette:{group:"DISPLAY"},templates:{create:"sap/ui/unified/designtime/CalendarLegend.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/Currency.designtime',[],function(){"use strict";return{name:{singular:"CURRENCY_NAME",plural:"CURRENCY_NAME_PLURAL"},palette:{group:"DISPLAY",icons:{svg:"sap/ui/unified/designtime/Currency.icon.svg"}},templates:{create:"sap/ui/unified/designtime/Currency.create.fragment.xml"}};},false);
sap.ui.predefine('sap/ui/unified/designtime/FileUploader.designtime',[],function(){"use strict";return{palette:{group:"INPUT",icons:{svg:"sap/ui/unified/designtime/FileUploader.icon.svg"}}};},false);
sap.ui.predefine('sap/ui/unified/designtime/library.designtime',[],function(){"use strict";return{};});
//# sourceMappingURL=library-preload.designtime.js.map
